Asent
================================

.. image:: https://img.shields.io/github/stars/kennethenevoldsen/asent.svg?style=social&label=Star&maxAge=2592000
   :target: https://github.com/kennethenevoldsen/asent

Asent is a rule-based sentiment model, building on `spaCy <https://spacy.io>`__, allowing the user
to take advantage of rules based on part-of-speech tags, names and much more. The
goal with asent is to have a fast and transparent sentiment pipeline, which is easily
customizable.



Contents
---------------------------------
  
The documentation consists of three parts:

- **Getting started** contains the installation instructions, guides, and tutorials on how to use asent.
- **Lexicon resources** contains the documentation on the resources used for each specific language.
- **API references** contains the documentation of each function and public class.

.. toctree::
   :maxdepth: 3
   :caption: Getting started

   installation
   introduction
   customizing
   languages

  

.. toctree::
   :caption: News

   news 

.. toctree::
   :caption: FAQ

   faq



.. toctree::
   :maxdepth: 3
   :caption: API references

   asent.visualize
   asent.getters
   asent.component
   


.. toctree::
   :caption: GitHub

   GitHub Repository <https://github.com/kennethenevoldsen/asent>


Indices and search
==================

* :ref:`genindex`
* :ref:`search`
